wnominate. Although it can easily be obtained from calling
the example in wnominate, it is included here to facilitate illustration
of the examples for the plot and summary functions.
data(sen90wnom)nomObject, which in this documentation is also referred to
as a W-NOMINATE object.nom33.dat file about
legislators. For a typical W-NOMINATE object run with an ORD file read using
readKH, it will contain the following:
stateState name of legislator.
icpsrStateICPSR state code of legislator.
cdCongressional District number.
icpsrLegisICPSR code of legislator.
partyParty of legislator.
partyCodeICPSR party code of legislator.
correctYeaPredicted Yeas and Actual Yeas.
wrongYeaPredicted Yeas and Actual Nays.
wrongNayPredicted Nays and Actual Yeas.
correctNayPredicted Nays and Actual Nays.
GMPGeometric Mean Probability.
PREProportional Reduction In Error.
coord1DFirst dimension W-NOMINATE score, with all subsequent dimensions
numbered similarly.
se1DBootstrapped standard error of first dimension W-NOMINATE score,
with all subsequent dimensions numbered similarly. This will be
empty if trials is set below 4.
corr.1Covariance between first and second dimension W-NOMINATE score,
with all subsequent dimensions numbered similarly.
nom33.dat file about
bills. For a typical W-NOMINATE object run with an ORD file read
using readKH, it will contain the following:
correctYeaPredicted Yeas and Actual Yeas.
wrongYeaPredicted Yeas and Actual Nays.
wrongNayPredicted Nays and Actual Yeas.
correctNayPredicted Nays and Actual Nays.
GMPGeometric Mean Probability.
PREProportional Reduction In Error.
spread1DFirst dimension W-NOMINATE spread, with all subsequent dimensions
numbered similarly.
midpoint1DFirst dimension W-NOMINATE midpoint, with all subsequent dimensions
numbered similarly.
#This data file is the same as that obtained using:
#data(sen90)
#sen90wnom<-wnominate(sen90,polarity=c(2,5))
data(sen90wnom)
summary(sen90wnom)
plot(sen90wnom)
Run the code above in your browser using DataLab