powered by
summary.nomObject reads a W-NOMINATE object and prints a summary.
summary.nomObject
# S3 method for nomObject summary(object,verbose=FALSE,...)
A summary of a wnominate object. Correct classification, APRE, and GMP are reported separately for each dimension.
wnominate
a wnominate output object.
logical, includes all ideal points if TRUE, otherwise only returns the first 10 legislators.
other arguments do nothing and are not passed to any functions.
Keith Poole [email protected]
Jeffrey Lewis [email protected]
James Lo [email protected]
Royce Carroll [email protected]
'wnominate', 'plot.coords', 'plot.scree', 'plot.angles', 'plot.cutlines', 'plot.nomObject'
#This data file is the same as that obtained using: #data(sen90) #sen90wnom<-wnominate(sen90,polarity=c(2,5)) data(sen90wnom) summary(sen90wnom) plot(sen90wnom)
Run the code above in your browser using DataLab