This dataframe contains the estimated ideal points of the 90th U.S Senate
using wnominate. Although it can easily be obtained from calling
the example in wnominate, it is included here to facilitate illustration
of the examples for the plot and summary functions.
Usage
data(sen90wnom)
Arguments
Value
An object of class nomObject, which in this documentation is also referred to
as a W-NOMINATE object.
legislatorsdata frame, containing all data from the old nom33.dat file about
legislators. For a typical W-NOMINATE object run with an ORD file read using
readKH, it will contain the following:
state
{State name of legislator.}
icpsrState{ICPSR state code of legislator.}
cd{Congressional District number.}
icpsrLegis{ICPSR code of legislator.}
party{Party of legislator.}
partyCode{ICPSR party code of legislator.}
correctYea{Predicted Yeas and Actual Yeas.}
wrongYea{Predicted Yeas and Actual Nays.}
wrongNay{Predicted Nays and Actual Yeas.}
correctNay{Predicted Nays and Actual Nays.}
GMP{Geometric Mean Probability.}
PRE{Proportional Reduction In Error.}
coord1D{First dimension W-NOMINATE score, with all subsequent dimensions
numbered similarly.}
se1D{Bootstrapped standard error of first dimension W-NOMINATE score,
with all subsequent dimensions numbered similarly. This will be
empty if trials is set below 4.}
corr.1{Covariance between first and second dimension W-NOMINATE score,
with all subsequent dimensions numbered similarly.}
item
rollcalls
wrongYea
wrongNay
correctNay
GMP
PRE
spread1D
midpoint1D
dimensions
eigenvalues
beta
weights
fits
code
readKH
itemize
correctYea
source
Keith Poole. 2005. 90th Senate Roll Call Vote Data.
http://www.voteview.com/.
#This data file is the same as that obtained using:#data(sen90)#sen90wnom<-wnominate(sen90,polarity=c(2,5)) data(sen90wnom)
summary(sen90wnom)
plot(sen90wnom)