Learn R Programming

wnominate (version 0.95)

wnominate: W-NOMINATE Roll Call Scaling

Description

wnominate is the function that takes a rollcall object and estimates Poole and Rosenthal W-NOMINATE scores with them.

Usage

wnominate(rcObject, ubeta=15, uweights=0.5, dims=2, minvotes=20,
        lop=0.025,trials=3, polarity, verbose=FALSE)

Arguments

rcObject
An object of class rollcall, from Simon Jackman's pscl package.
ubeta
integer, beta parameter for NOMINATE. It is strongly recommended that you do not change the default.
uweights
integer, weight parameter for NOMINATE. It is strongly recommended that you do not change the default.
dims
integer, number of dimensions to estimate. Must be nonnegative and cannot exceed 10 dimensions.
minvotes
minimum number of votes a legislator must vote in for them to be analyzed.
lop
A proportion between 0 and 1, the cut-off used for excluding lopsided votes, expressed as the proportion of non-missing votes on the minority side. The default, lop=0.025, eliminates votes where the minority
trials
integer, number of bootstrap trials for standard errors. Any number set below 4 here will not return any standard errors. Setting this number to be large will slow execution of W-NOMINATE considerably.
polarity
a vector specifying the legislator in the data set who is conservative on each dimension. For example, c(3,5) indicates legislator 3 is conservative on dimension 1, and legislator 5 is conservative on
verbose
logical, indicates whether bills and legislators to be deleted should be printed while data is being checked before ideal points are estimated.

Value

  • An object of class nomObject, which in this documentation is also referred to as a W-NOMINATE object.
  • legislatorsdata frame, containing all data from the old nom31.dat file about legislators. For a typical W-NOMINATE object run with an ORD file read using readKH, it will contain the following:
    • state
    {State name of legislator.} icpsrState{ICPSR state code of legislator.} cd{Congressional District number.} icpsrLegis{ICPSR code of legislator.} party{Party of legislator.} partyCode{ICPSR party code of legislator.} correctYea{Predicted Yeas and Actual Yeas.} wrongYea{Predicted Yeas and Actual Nays.} wrongNay{Predicted Nays and Actual Yeas.} correctNay{Predicted Nays and Actual Nays.} GMP{Geometric Mean Probability.} PRE{Proportional Reduction In Error.} coord1D{First dimension W-NOMINATE score, with all subsequent dimensions numbered similarly.} se1D{Bootstrapped standard error of first dimension W-NOMINATE score, with all subsequent dimensions numbered similarly. This will be empty if trials is set below 4.} corr.1{Covariance between first and second dimension W-NOMINATE score, with all subsequent dimensions numbered similarly.}

item

  • rollcalls
  • wrongYea
  • wrongNay
  • correctNay
  • GMP
  • PRE
  • spread1D
  • midpoint1D
  • dimensions
  • eigenvalues
  • beta
  • weights
  • fits

code

readKH

itemize

  • correctYea

References

Jeffrey Lewis. http://adric.sscnet.ucla.edu/rollcall/ Keith Poole and Howard Rosenthal. 1997. 'Congress: A Political-Economic History of Roll Call Voting.' New York: Oxford University Press. Keith Poole. http://voteview.ucsd.edu/ Keith Poole, Jeffrey Lewis, James Lo, and Royce Carroll. 2011. `Scaling Roll Call Votes with WNOMINATE in R.' Journal of Statistical Software, 42(14), 1-21. http://www.jstatsoft.org/v42/i14/

See Also

'generateTestData','plot.nomObject','summary.nomObject'.

Examples

Run this code
#This data file is the same as reading file using:
    #sen90 <- readKH("ftp://voteview.com/sen90kh.ord")
    #All ORD files can be found on www.voteview.com
    data(sen90)
    
    summary(sen90)
    result<-wnominate(sen90,polarity=c(2,5))
    #'result' is the same nomObject as found in 
    #data(sen90nomObject)
    summary(result)
    plot(result)

Run the code above in your browser using DataLab